striplog
========

.. image:: https://pypip.in/version/striplog/badge.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Latest version
    
.. image:: https://pypip.in/status/striplog/badge.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Development status

.. image:: https://www.codacy.com/project/badge/ad9af103cba14d33abd5b327727ff644 
    :target: https://www.codacy.com/public/matt/striplog
    :alt: Code review

.. image:: https://pypip.in/license/striplog/badge.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: License

Lithology and stratigraphic logs for wells. 

Utilities for handling lithologic and stratigraphic 'interval' logs. Includes a version of `las.py` for loading LAS well log data. 

Docs
----

* `Read The Docs <https://pythonhosted.org/striplog/>`_

Dependencies
------------

* `NumPy <http://www.numpy.org/>`_
* `Pillow <https://pillow.readthedocs.org/>`_
* `matplotlib <http://matplotlib.org/>`_

Install
-------

* ``pip install striplog``
